client

package
v0.10.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 18, 2026 License: Apache-2.0 Imports: 14 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Run added in v0.6.5

func Run()

Run initializes the client configuration, sets up the watcher, creates the task, adds the task to the watcher, waits for deployment and handles any errors in the process.

Types

type Config added in v0.9.0

type Config struct {
	Url                    string        `env:"ARGO_WATCHER_URL,required"`
	Images                 []string      `env:"IMAGES,required"`
	Tag                    string        `env:"IMAGE_TAG,required"`
	App                    string        `env:"ARGO_APP,required"`
	Author                 string        `env:"COMMIT_AUTHOR,required"`
	Project                string        `env:"PROJECT_NAME,required"`
	Token                  string        `env:"ARGO_WATCHER_DEPLOY_TOKEN"`
	JsonWebToken           string        `env:"BEARER_TOKEN"`
	Timeout                time.Duration `env:"TIMEOUT" envDefault:"60s"`
	TaskTimeout            int           `env:"TASK_TIMEOUT"`
	RetryInterval          time.Duration `env:"RETRY_INTERVAL" envDefault:"15s"`
	ExpectedDeploymentTime time.Duration `env:"EXPECTED_DEPLOY_TIME" envDefault:"15m"`
	Debug                  bool          `env:"DEBUG"`
}

func NewClientConfig added in v0.6.5

func NewClientConfig() (*Config, error)

NewClientConfig parses the environment variables to fill a Config struct and returns the new instance or an error.

type Watcher

type Watcher struct {
	// contains filtered or unexported fields
}

func NewWatcher added in v0.6.5

func NewWatcher(baseUrl string, debugMode bool, timeout time.Duration) *Watcher

NewWatcher creates a new Watcher instance with the given base URL, timeout, and debug mode.

Jump to